Struct GroundQuadPattern
pub struct GroundQuadPattern {
pub subject: GroundTermPattern,
pub predicate: NamedNodePattern,
pub object: GroundTermPattern,
pub graph_name: GraphNamePattern,
}Available on crate feature
rdf only.Expand description
A triple pattern in a specific graph without blank nodes.
Fields
subject: GroundTermPatternpredicate: NamedNodePatternobject: GroundTermPatterngraph_name: GraphNamePatternTrait Implementations
impl Clone for GroundQuadPattern
impl Clone for GroundQuadPattern
fn clone(&self) -> GroundQuadPattern
fn clone(&self) -> GroundQuadPattern
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) ยท Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Debug for GroundQuadPattern
impl Debug for GroundQuadPattern
impl Display for GroundQuadPattern
impl Display for GroundQuadPattern
impl Hash for GroundQuadPattern
impl Hash for GroundQuadPattern
impl PartialEq for GroundQuadPattern
impl PartialEq for GroundQuadPattern
fn eq(&self, other: &GroundQuadPattern) -> bool
fn eq(&self, other: &GroundQuadPattern) -> bool
Tests for
self and other values to be equal, and is used by ==.impl TryFrom<QuadPattern> for GroundQuadPattern
impl TryFrom<QuadPattern> for GroundQuadPattern
fn try_from(
pattern: QuadPattern,
) -> Result<GroundQuadPattern, <GroundQuadPattern as TryFrom<QuadPattern>>::Error>
fn try_from( pattern: QuadPattern, ) -> Result<GroundQuadPattern, <GroundQuadPattern as TryFrom<QuadPattern>>::Error>
Performs the conversion.
impl Eq for GroundQuadPattern
impl StructuralPartialEq for GroundQuadPattern