Struct NamedNode
pub struct NamedNode {
iri: String,
}Available on crate feature
rdf only.Expand description
An owned RDF IRI.
The default string formatter is returning an N-Triples, Turtle, and SPARQL compatible representation:
use oxrdf::NamedNode;
assert_eq!(
"<http://example.com/foo>",
NamedNode::new("http://example.com/foo")?.to_string()
);Fields
iri: StringImplementations
impl NamedNode
impl NamedNode
pub fn new(iri: impl Into<String>) -> Result<NamedNode, IriParseError>
pub fn new(iri: impl Into<String>) -> Result<NamedNode, IriParseError>
Builds and validate an RDF IRI.
pub fn new_unchecked(iri: impl Into<String>) -> NamedNode
pub fn new_unchecked(iri: impl Into<String>) -> NamedNode
Builds an RDF IRI from a string.
It is the callerโs responsibility to ensure that iri is a valid IRI.
NamedNode::new() is a safe version of this constructor and should be used for untrusted data.
pub fn as_str(&self) -> &str
pub fn into_string(self) -> String
pub fn as_ref(&self) -> NamedNodeRef<'_>