Struct Variable
pub struct Variable {
name: String,
}Available on crate feature
rdf only.Expand description
A SPARQL query owned variable.
The default string formatter is returning a SPARQL compatible representation:
use oxrdf::{Variable, VariableNameParseError};
assert_eq!("?foo", Variable::new("foo")?.to_string());Fields
name: StringImplementations
impl Variable
impl Variable
pub fn new(name: impl Into<String>) -> Result<Variable, VariableNameParseError>
pub fn new(name: impl Into<String>) -> Result<Variable, VariableNameParseError>
Creates a variable name from a unique identifier.
The variable identifier must be valid according to the SPARQL grammar.
pub fn new_unchecked(name: impl Into<String>) -> Variable
pub fn new_unchecked(name: impl Into<String>) -> Variable
Creates a variable name from a unique identifier without validation.
It is the callerโs responsibility to ensure that id is a valid blank node identifier
according to the SPARQL grammar.
Variable::new() is a safe version of this constructor and should be used for untrusted data.
pub fn as_str(&self) -> &str
pub fn into_string(self) -> String
pub fn as_ref(&self) -> VariableRef<'_>